@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: API2.pm,v 1.82 2005/06/17 19:43:45 fredo Exp $
+#   $Id: API2.pm,v 1.83 2005/09/12 16:54:21 fredo Exp $
 #
 #=======================================================================
 
@@ -37,7 +37,7 @@ BEGIN {
 
     use vars qw( $VERSION $seq @FontDirs );
 
-    ($VERSION) = sprintf '%i.%03i', split(/\./,('$Revision: 1.82 $' =~ /Revision: (\S+)\s/)[0]);  # $Date: 2005/06/17 19:43:45 $
+    ($VERSION) = sprintf '%i.%03i', split(/\./,('$Revision: 1.83 $' =~ /Revision: (\S+)\s/)[0]);  # $Date: 2005/09/12 16:54:21 $
 
     @FontDirs = ( (map { "$_/PDF/API2/fonts" } @INC), 
         qw[ /usr/share/fonts /usr/local/share/fonts c:/windows/fonts c:/winnt/fonts ] );
@@ -1591,6 +1591,9 @@ Valid %options are:
 
   '-encode' ... changes the encoding of the font from its default.
 
+  '-isocmap' ... per default the MS Unicode Map is used, if this 
+                 option is given the ISO Unicode Map will be used.
+
 =cut
 
 sub ttfont {
@@ -2401,6 +2404,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: API2.pm,v $
+    Revision 1.83  2005/09/12 16:54:21  fredo
+    added -isocmap option
+
     Revision 1.82  2005/06/17 19:43:45  fredo
     fixed CPAN modulefile versioning (again)
 
