@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: WebColor.pm,v 1.6 2004/12/16 00:30:54 fredo Exp $
+#   $Id: WebColor.pm,v 1.9 2005/06/17 19:44:03 fredo Exp $
 #
 #=======================================================================
 
@@ -44,7 +44,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::ColorSpace::Indexed );
 
-    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/12/16 00:30:54 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.9 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/06/17 19:44:03 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -129,6 +129,15 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: WebColor.pm,v $
+    Revision 1.9  2005/06/17 19:44:03  fredo
+    fixed CPAN modulefile versioning (again)
+
+    Revision 1.8  2005/06/17 18:53:34  fredo
+    fixed CPAN modulefile versioning (dislikes cvs)
+
+    Revision 1.7  2005/03/14 22:01:27  fredo
+    upd 2005
+
     Revision 1.6  2004/12/16 00:30:54  fredo
     added no warn for recursion
 
