@@ -38,7 +38,7 @@
 #   FREE SOFTWARE FOUNDATION, INC., 59 TEMPLE PLACE - SUITE 330,
 #   BOSTON, MA 02111-1307, USA.
 #
-#   $Id: CoreFont.pm,v 1.13 2005/06/17 19:44:03 fredo Exp $
+#   $Id: CoreFont.pm,v 1.14 2005/09/12 16:56:20 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::Font::CoreFont;
@@ -76,7 +76,7 @@ BEGIN {
 
     @ISA=qw(PDF::API2::Resource::Font);
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.13 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/06/17 19:44:03 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.14 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/09/12 16:56:20 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -108,6 +108,9 @@ sub _look_for_font ($)
     eval "require PDF::API2::Resource::Font::CoreFont::$fname; ";
     unless($@)
     {
+	no strict 'refs';
+        my $obj = "PDF::API2::Resource::Font::CoreFont::".$fname;
+	$fonts->{$fname} = deep_copy(${$obj."::FONTDATA"});
         $fonts->{$fname}->{uni}||=[];
         foreach my $n (0..255) 
         {
@@ -121,6 +124,36 @@ sub _look_for_font ($)
     }
 }
 
+#
+# Deep copy something, thanks to Randal L. Schwartz
+# Changed to deal w/ CODE refs, in which case it doesn't try to deep copy
+#
+sub deep_copy
+{
+    my $this = shift;
+    if (not ref $this) 
+    {
+	$this;
+    } 
+    elsif (ref $this eq "ARRAY") 
+    {
+	[map &deep_copy($_), @$this];
+    } 
+    elsif (ref $this eq "HASH") 
+    {
+	+{map { $_ => &deep_copy($this->{$_}) } keys %$this};
+    } 
+    elsif (ref $this eq "CODE") 
+    {
+	# Can't deep copy code refs
+	return $this;
+    } 
+    else 
+    { 
+	die "what type is $_?";
+    }
+}
+
 sub _look_for_fontfile ($) 
 {
     my $fname=shift;
@@ -418,6 +451,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: CoreFont.pm,v $
+    Revision 1.14  2005/09/12 16:56:20  fredo
+    applied mod_perl patch by Paul Schilling <pfschill@sbcglobal.net>
+
     Revision 1.13  2005/06/17 19:44:03  fredo
     fixed CPAN modulefile versioning (again)
 
