@@ -27,11 +27,12 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: helveticaboldoblique.pm,v 1.7 2005/06/07 23:21:39 fredo Exp $
+#   $Id: helveticaboldoblique.pm,v 1.8 2005/09/12 16:56:22 fredo Exp $
 #
 #=======================================================================
+package PDF::API2::Resource::Font::CoreFont::helveticaboldoblique;
 
-$fonts->{helveticaboldoblique}= {
+$FONTDATA = {
     'fontname' => 'Helvetica-BoldOblique',
     'type' => 'Type1',
     'apiname' => 'HeBi',
@@ -550,6 +551,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: helveticaboldoblique.pm,v $
+    Revision 1.8  2005/09/12 16:56:22  fredo
+    applied mod_perl patch by Paul Schilling <pfschill@sbcglobal.net>
+
     Revision 1.7  2005/06/07 23:21:39  fredo
     fontkey correction
 
